.. _child_example_three-name:

!!!!!!!!!!!!!!!!!!!
child_example_three
!!!!!!!!!!!!!!!!!!!

.. meta::
  :keywords: child_example_three,third,child,example,page,links,this,file

.. index:: child_example_three, third, child, page

.. _child_example_three-title:

Third Child Example Page
########################

.. contents::
  :local:

.. index:: links

.. _child_example_three@Links:

Links
*****
- :ref:`parent<toc_list_example-title>`
- :ref:`first child<child_example_one-title>`
- :ref:`second child<child_example_two-title>`

.. _child_example_three@This Example File:

This Example File
*****************
:ref:`child_example_two@This Example File`
is the same as for the second child page.
